MiniloHeaderMenuChip class

Annotations

Constructors

MiniloHeaderMenuChip({required IconData icon, VoidCallback? onTap, int? badgeCount, double width = 58})
const

Properties

badgeCount int?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited