MiniloShadows class

Annotations

Constructors

MiniloShadows({required List<BoxShadow> sm, required List<BoxShadow> md, required List<BoxShadow> lg})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg List<BoxShadow>
final
md List<BoxShadow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm List<BoxShadow>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(MiniloShadows a, MiniloShadows b, double t) MiniloShadows

Constants

standard → const MiniloShadows